@@ -2,6 +2,7 @@
 import json
 import urllib
 
+import options
 from constants import (BREADTH_FIRST, DEPTH_FIRST,
                        STOP_AT_END_OF_GRAPH,
                        NODE_GLOBAL, NODE_PATH, NODE_RECENT,
@@ -11,6 +12,9 @@ from constants import (BREADTH_FIRST, DEPTH_FIRST,
                        INDEX_FULLTEXT)
 from request import Request, NotFoundError, StatusException
 
+__all__ = ["GraphDatabase", "Incoming", "Outgoing", "Undirected",
+           "StopAtDepth", "NotFoundError", "StatusException"]
+
 
 class StopAtDepth(object):
     """
@@ -166,7 +170,11 @@ class Base(object):
         if response.status == 200:
             self._dic["data"][key] = json.loads(content)
         else:
-            raise NotFoundError(response.status, "Node or propery not found")
+            if options.SMART_ERRORS:
+                raise KeyError()
+            else:
+                raise NotFoundError(response.status,
+                                    "Node or propery not found")
         return self._dic["data"][key]
 
     def get(self, key, *args):
@@ -201,7 +209,11 @@ class Base(object):
         if response.status == 204:
             del self._dic["data"][key]
         elif response.status == 404:
-            raise NotFoundError(response.status, "Node or property not found")
+            if options.SMART_ERRORS:
+                raise KeyError()
+            else:
+                raise NotFoundError(response.status,
+                                    "Node or propery not found")
         else:
             raise StatusException(response.status, "Node or propery not found")
 
@@ -356,14 +368,14 @@ class Node(Base):
         if isinstance(stop, (int, float)):
             data.update({"max depth": stop})
         elif stop is STOP_AT_END_OF_GRAPH:
-            data.update({'prune evaluator':{
-                            'language':'javascript',
-                            'body':'false',
+            data.update({'prune evaluator': {
+                'language': 'javascript',
+                'body': 'false',
             }})
         if returnable in (BREADTH_FIRST, DEPTH_FIRST):
             data.update({"return filter": {
-                            "language": "builtin",
-                            "name": returnable,
+                "language": "builtin",
+                "name": returnable,
             }})
         if uniqueness in (NODE_GLOBAL, NODE_PATH, NODE_RECENT, NODE,
                           RELATIONSHIP_GLOBAL, RELATIONSHIP_PATH,
@@ -474,7 +486,10 @@ class IndexesProxy(dict):
             elif "default" in kwargs:
                 return kwargs["default"]
             else:
-                raise NotFoundError()
+                if options.SMART_ERRORS:
+                    raise KeyError()
+                else:
+                    raise NotFoundError()
 
     def items(self):
         return self._dict.items()
@@ -522,6 +537,8 @@ class Index(object):
                 raise TypeError("%s is a %s and the index is for %ss"
                                 % (item, self._index_for.capitalize(),
                                    self._index_for))
+            #TODO
+            #value = urllib.quote(value.encode('utf-8')) #Needs more testing
             value = urllib.quote(value)
             if isinstance(item, Base):
                 url_ref = item.url
@@ -592,6 +609,7 @@ class Index(object):
     def get(self, key, value=None):
         key = urllib.quote(key)
         if value:
+            value = urllib.quote(value)
             return self.IndexKey(self._index_for,
                                  "%s/%s" % (self.url, key))[value]
         else:
@@ -621,8 +639,26 @@ class Index(object):
         elif response.status != 204:
             raise StatusException(response.status)
 
-    def query(self, key, value):
-        return self.get(key).query(value)
+    def query(self, *args):
+        """
+        Query a fulltext index by key and query or just a plain Lucene query, eg
+
+        i1 = gdb.nodes.indexes.get('people',type='fulltext', provider='lucene')
+        i1.query('name','do*')
+        i1.query('name:do*')
+
+        In this example, the last two line are equivalent.
+        """
+        if not args or len(args) > 2:
+            raise TypeError('query() takes 2 or 3 arguments (a query or a key and'
+                            ' a query) (%d given)' % (len(args) + 1))
+        elif len(args) == 1:
+            # TODO: Add a Q class in order to do complex queries
+            query, = args
+            return self.get('ridiculouskey123').query(query)
+        else:
+            key, query = args
+            return self.get(key).query(query)
 
 
 class RelationshipsProxy(dict):
